<?php

class ControllerExtensionPaymentErip extends Controller
{
    public function index()
    {
        $this->load->model('checkout/order');
        $this->load->language('extension/payment/erip');
        $data['text_loading'] = $this->language->get('text_loading');
        $data['button_confirm'] = $this->language->get('button_confirm');
        $order_info = $this->model_checkout_order->getOrder($this->session->data['order_id']);
        $data['action'] = 'https://ssl.easypay.by/weborder/?EP_Module=opencart_3.0';
        $data['merchant'] = $this->config->get('payment_erip_merchant');
        $data['order_id'] = $this->session->data['order_id'];
        $data['description'] = html_entity_decode($this->config->get('config_store'), ENT_QUOTES, 'UTF-8');
        $data['expires'] = $this->config->get('payment_erip_expires');

        $data['hash'] = md5(
            $this->config->get('payment_erip_merchant')
            . $this->config->get('payment_erip_webkey')
            . $this->session->data['order_id']
            . $order_info['total']
        );

        $data['amount'] = $order_info['total'];
        $data['return'] = $this->url->link('extension/payment/erip/success');
        $data['fail'] = $this->url->link('extension/payment/erip/fail');
        $data['EP_OrderInfo'] = 'Заказ от магазина ' . $order_info['store_name'];
        $data['EP_Comment'] = 'Заказ №' . $data['order_id'];

        $this->model_checkout_order->addOrderHistory(
            $this->session->data['order_id'],
            $this->config->get('payment_erip_order_status_id')
        );

        return $this->load->view('extension/payment/erip', $data);
    }

    public function fail()
    {
        $this->cart->clear();
        $order_id = $this->request->get['EP_OrderNo'];
        $data['order_id'] = $order_id;
        $this->template = 'extension/payment/erip_failure';
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['column_right'] = $this->load->controller('common/column_right');
        $data['content_top'] = $this->load->controller('common/content_top');
        $data['content_bottom'] = $this->load->controller('common/content_bottom');
        $data['footer'] = $this->load->controller('common/footer');
        $data['header'] = $this->load->controller('common/header');

        $this->load->model('checkout/order');
        $this->model_checkout_order->addOrderHistory(
            $order_id,
            $this->config->get('payment_erip_canceled_status_id'),
            '',
            true
        );

        $this->response->setOutput($this->load->view('extension/payment/erip_failure', $data));
    }

    public function success()
    {
        $order_id = $this->request->get['EP_OrderNo'];
        $data['order_id'] = $order_id;

        $this->cart->clear();

        $this->template = 'extension/payment/erip_success';
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['column_right'] = $this->load->controller('common/column_right');
        $data['content_top'] = $this->load->controller('common/content_top');
        $data['content_bottom'] = $this->load->controller('common/content_bottom');
        $data['footer'] = $this->load->controller('common/footer');
        $data['header'] = $this->load->controller('common/header');

        $this->response->setOutput($this->load->view('extension/payment/erip_success', $data));

    }

    public function notify()
    {
        $values = [
            'order_mer_code' => empty($this->request->post['order_mer_code']) ? '' : $this->request->post['order_mer_code'],
            'sum' => empty($this->request->post['sum']) ? '' : $this->request->post['sum'],
            'mer_no' => empty($this->request->post['mer_no']) ? '' : $this->request->post['mer_no'],
            'card' => empty($this->request->post['card']) ? '' : $this->request->post['card'],
            'purch_date' => empty($this->request->post['purch_date']) ? '' : $this->request->post['purch_date'],
            'notify_signature' => empty($this->request->post['notify_signature']) ? '' : $this->request->post['notify_signature'],
            'web_key' => $this->config->get('payment_erip_webkey'),
        ];

        $signature_checked = $this->validateRequest($values);

        if ($signature_checked) {
            $this->load->model('checkout/order');
            $this->model_checkout_order->addOrderHistory(
                $values['order_mer_code'],
                $this->config->get('payment_erip_processing_status_id'),
                '',
                true
            );

            header('HTTP/1.0 200 OK');
            print $status = 'OK | the notice is processed';

        } else {
            header('HTTP/1.0 400 Bad Request');
            print $status = 'FAILED | the notice is not processed';
        }
    }

    private function validateRequest($request)
    {
        $signature_checked = false;

        if (($request['order_mer_code'] != '') &&
            ($request['sum'] != '') &&
            ($request['mer_no'] != '') &&
            ($request['card'] != '') &&
            ($request['purch_date'] != '')
        ) {
            $hash = md5($request['order_mer_code'] .
                        $request['sum'] .
                        $request['mer_no'] .
                        $request['card'] .
                        $request['purch_date'] .
                        $request['web_key']);

            if ($hash === $request['notify_signature']) {
                $signature_checked = true;
            }
        }

        return $signature_checked;
    }
}
